@@ -13,7 +13,7 @@ C
       INTEGER TYPE
       DOUBLE PRECISION ETA, ARE, MRE
 C
-      DOUBLE PRECISION K(1), QK(1), SR, SI, U, V, A, B, C, D,
+      DOUBLE PRECISION K(*), QK(*), SR, SI, U, V, A, B, C, D,
      1 A1, A2, A3, A6, A7, E, F, G, H, SZR, SZI,
      2 LZR, LZI
 C SYNTHETIC DIVISION OF K BY THE QUADRATIC 1,U,V
