@@ -1,4 +1,4 @@
-      subroutine setfor (PRE1,PRV1,TIM1)
+      subroutine setfor (PRE1,PRV1,TIM1, PRE2, PRV2)
       IMPLICIT NONE
       INTEGER I
 c      INCLUDE 'model.txt'
@@ -20,7 +20,7 @@ c      COMMON/SERIES/NAME,LEN,TIM,SER,TDIF
       COMMON/SERIES/TIM,SER,TDIF,NAME,LEN
 C*****kfasav.txt
       DOUBLE PRECISION PRE(5000),PRV(5000),FSER(5000),FVAR(5000)
-     1,SSER(5000),SVAR(5000)
+     1,SSER(5000),SVAR(5000), PRE2(5000), PRV2(5000)
       DOUBLE PRECISION FSES(5000,20),FSCV(5000,20,20),SSES(5000,20)
      1,SSCV(5000,20,20),PSES(5000,20),PSCV(5000,20,20),TRAN(5000,20,20)
 c      COMMON/KFASAV/PRE,PRV,FSER,FVAR,SSER,SVAR,FSES,FSCV,SSES,SSCV
@@ -34,6 +34,8 @@ C*****series1.txt
 
       DO 90 I=1,LEN+FOR
          TIM1(I)=TIM(I)
+         PRE2(I)=PRE(I)
+         PRV2(I)=PRV(I)
  90   CONTINUE
       
       IF(fct.EQ.0)then
